===============
ATSAS pipelines
===============

.. image:: https://img.shields.io/travis/mrakitin/atsas-pipelines.svg
        :target: https://travis-ci.org/mrakitin/atsas-pipelines

.. image:: https://img.shields.io/pypi/v/atsas-pipelines.svg
        :target: https://pypi.python.org/pypi/atsas-pipelines


ATSAS pipelines for the NSLS-II LIX beamline

* Free software: 3-clause BSD license
* Documentation: https://mrakitin.github.io/atsas-pipelines.
